% Description: demonstrates the usage of the RTD suite of MATLAB routines
% 
% Syntax: Demo_RTD
% 
% Inputs:  None.  This demonstration routine automatically reads the RT datasets (RT1  
%          and RT2) of two PVT sessions from the sample_data.mat file provided with this suite  
%          for computing their divergence. 
% 
% Outputs: the RTD values between the entire distributions (L = 0 msec and U = 10 min) as well  
%          as portions of the distributions (L = 250, 500, and 1000 msec and U = 10 min) of RT1   
%          and RT2.  (L  lower limit of the distribution; U  upper limit of the distribution.)



clear all

load sample_data   % sample RT datasets

% Computes RTD between RT1 and RT2 between limits 0 msec and 10 min
RTD_0_above = RTD_eval(RT1,RT2,0,10*60*1000);

% Computes RTD between RT1 and RT2 between limits 250 msec and 10 min
RTD_250_above = RTD_eval(RT1,RT2,250,10*60*1000);

% Computes RTD between RT1 and RT2 between limits 500 msec and 10 min
RTD_500_above = RTD_eval(RT1,RT2,500,10*60*1000);

% Computes RTD between RT1 and RT2 between limits 1000 msec and 10 min
RTD_1000_above = RTD_eval(RT1,RT2,1000,10*60*1000);

disp(['The RTD from 0 ms and above is ',num2str(RTD_0_above,'%0.3f')])

disp(['The RTD from 250 ms and above is ',num2str(RTD_250_above,'%0.3f')])

disp(['The RTD from 500 ms and above is ',num2str(RTD_500_above,'%0.3f')])

disp(['The RTD from 1000 ms and above is ',num2str(RTD_1000_above, '%0.3f')])