function RTD = RTD_eval(RT1,RT2,L,U)
% Description: (This is the routine used to compute the RTD metric.) computes the RTD between two RT samples within any interval.  This routine is 
%              called by Demo_RTD.m
% 
% Syntax: RTD = RTD_eval(RT1,RT2,L,U)
% 
% Inputs: RT1  RT dataset (msec) at PVT session 1
%         RT2  RT dataset (msec) at PVT session 2
%         L  lower limit (msec) of the distribution
%         U  upper limit (msec) of the distribution
%                  
% Output: RTD  the RTD between RT1 and RT2
% 
% Note that RTD_eval(RT1,RT2,L,U) = - RTD_eval(RT2,RT1,L,U)
 
Nt = length(RT1);

% Here RT2 is the baseline RTs and RT1 is the RTs at the sleep-deprived
% session

defaultStream = RandStream.getDefaultStream;
savedState = defaultStream.State;

if isequal(RT1,RT2)
    
    RT1 = RT1(unidrnd(length(RT1),size(RT1)));
    defaultStream.State = savedState;
    
    
else
    
end


[RT1,h1,lambda1] = RT_censoring(RT1);

[RT2,h2,lambda2] = RT_censoring(RT2);

norm_fac1 = cdf_kde(U,RT1,h1,lambda1) - cdf_kde(L,RT1,h1,lambda1);

norm_fac2 = cdf_kde(U,RT2,h2,lambda2) - cdf_kde(L,RT2,h2,lambda2);

%==================================  RTD calculation ====================%

f1 = @(x,varargin) pdf_kde(x,RT1,h1,lambda1)/(eps+norm_fac1);
 
f2 = @(x,varargin) pdf_kde(x,RT2,h2,lambda2)/(eps+norm_fac2); 

a = quadgk(@(x,varargin) f1(x).*log(f1(x)+eps),L,U,'RelTol',1e-7,'AbsTol',1e-9);

b = quadgk(@(x,varargin) f2(x).*log(f2(x)+eps),L,U,'RelTol',1e-7,'AbsTol',1e-9);

c = quadgk(@(x,varargin) -(f1(x)+f2(x)).*log(0.5*(f1(x)+f2(x))+eps),L,U,'RelTol',1e-7,'AbsTol',1e-9);

RTD = sqrt(0.5*(a+b+c)); 

RT1(RT1 < L | RT1 > U) = [];
RT2(RT2 < L | RT2 > U) = [];

if isempty(RT2) 
    
    RTD = RTD;
    
elseif isempty(RT1)
    
    RTD = -RTD;
    
else
    
 [H,~,~,dir] = Modified_kstest2(RT1,RT2);
    
 
if H
    
 RTD = (-1)*sign(dir)*RTD;  
    
else
    
 
 RTD = -RTD;  % The two distributions are indistinguishable.
    
end
    
end

RTD = (Nt/sqrt(log(2)))*RTD;


