function [RT,h,lambda] = RT_censoring(data)
% Description: computes the optimal bin width and the Box-Cox transformation parameter.  This 
%              routine is called by RT_eval.m
% 
% Syntax: [RT,h,lambda] = RT_censoring(data)
% 
% Input: a column vector containing measured RT samples in msec                 
% 
% Outputs: RT  RT samples (msec) used by the Kernel density estimator (a column vector)
%          h  optimal bin width of the Kernel density estimator
%          lambda  Box-Cox transformation parameter




%Ignore responses faster than 100 milisec 
data(data<=100) = [];

RT = reshape(data,max(size(data)),1);

clear sols y;

y = sort(RT);

% Finds the lambda that yields the most normal
% box-cox-transformed data
options = optimset('TolX',1e-7,'MaxIter',4000,'MaxFunEvals',4000,'Display','Off','TolFun',1e-7);
%lambda = fminsearch(@(x) NormalityTest(boxc_trans(y,x)),-4,options);
lambda = fminbnd(@(x) NormalityTest(boxc_trans(y,x)),-6,6,options);

% Box-Cox transformation
RT_trans = boxc_trans(y,lambda);

% Optimal bin-width estimate 
h = bandwidth_estimate(RT_trans);


%% --------------------------------------------------------------------- %%
%% To compute the probability plot correlation coefficient for the input data

function stat = NormalityTest(data)
% stat = NormalityTest(data)

y = sort(data);

y1 = (y - mean(y))/std(y);

phi = normcdf(y1);

l = length(y);

stat = -l - mean((2*[1:l]'-1).*log(phi+realmin) + (2*(l - [1:l]') + 1).*log(1-phi+realmin));

stat = stat*(1 + 4/l - 25/l^2);

