function bdata = boxc_trans(x,lam)
% Description: transforms the input RT data into a Box-Cox-transformed data.  This routine is 
%              called by RT_censoring.m
% 
% Syntax: RT_trans = boxc_trans(RT,lambda)
% 
% Inputs: RT  a column vector containing measured RT samples (msec)
%         lambda  Box-Cox transformation parameter 
%                
% Output: RT_trans  the Box-Cox-transformed RT sample


if abs(lam) > eps(1)
    
    bdata = ((1+x).^lam -1)/lam;
    
else
    
    bdata = log(1+x);
    
end