function g = cdf_kde(x,RT,h,lambda)
% Description: computes the cumulative density function (CDF) of the Kernel density estimator.  
% 
% Syntax: g = cdf_kde(x,RT,h,lambda)
% 
% Inputs: x  a vector of points (msec) for which the CDF needs to be evaluated
%         RT  a column vector containing measured RT samples (msec)
%         h  optimal bin width of the Kernel density estimator
%         lambda  Box-Cox transformation parameter
% 
% Output: g  CDF of the Kernel estimator of the RT data evaluated at data points x


st_dev = 1;

x = x/st_dev;

RT = RT/st_dev;

size_x = size(x);

x = reshape(x,max(size_x),min(size_x));  

y = boxc_trans(x,lambda);

size_RT = size(RT);

RT_trans = boxc_trans(RT,lambda);

RT_trans = reshape(RT_trans,max(size_RT),min(size_RT));

Y = y*ones(1,length(RT)); 

MU = RT_trans*ones(1,length(y)); 

norm_const = 1/length(RT_trans)*sum(normcdf(boxc_trans(Inf,lambda),RT_trans,h)) - 1/length(RT_trans)*sum(normcdf(boxc_trans(0,lambda),RT_trans,h));

f =  mean(normcdf((Y-MU')./h)-normcdf((boxc_trans(0,lambda)*ones(length(y),length(RT)) - MU')./h),2)/norm_const;

f = reshape(f,size_x(1),size_x(2));

g = f;

return;

