function f = pdf_kde(x,RT,h,lambda)
% Description: computes the probability density function (PDF) of the Kernel density estimator.  
%              This routine is called by RTD_eval.m 
% 
% Syntax: f = pdf_kde(x,RT,h,lambda)
% 
% Inputs: x  a vector of points (msec) for which the PDF needs to be evaluated 
%         RT  a column vector containing measured RT samples (msec) 
%         h  optimal bin width of the Kernel density estimator
%         lambda  Box-Cox transformation parameter 
%               
% Output: f  PDF of the Kernel estimator of the RT data evaluated at data points x

 
st_dev = 1;

x = x/st_dev;

RT = RT/st_dev;

size_x = size(x);

x = reshape(x,max(size_x),min(size_x));

y = boxc_trans(x,lambda);

size_RT = size(RT);

RT_trans = boxc_trans(RT,lambda);

RT_trans = reshape(RT_trans,max(size_RT),min(size_RT));

Y = y*ones(1,length(RT));

MU = RT_trans*ones(1,length(y));

norm_const = 1/length(RT_trans)*sum(normcdf(boxc_trans(Inf,lambda),RT_trans,h)) - 1/length(RT_trans)*sum(normcdf(boxc_trans(0,lambda),RT_trans,h));

f =  mean(normpdf(Y-MU',0,h),2).*(x+1).^(lambda-1)/norm_const;

f = reshape(f/st_dev,size_x(1),size_x(2));

return;

